==> backup_tracker_micro-0.1.0.tar.gz: backup_tracker_micro-0.1.0/src/backup_tracker_micro/backup.py <==

import json

from enum import Enum

from rest_client_micro import BaseRESTAPI


class BackupEvent(Enum):
    STARTED = "started"
    FINISHED = "finished"


class BackupTracker(BaseRESTAPI):

    host: str
    service: str

    def __init__(self, host: str, service: str, root_endpoint: str, config_dir: str = None, cache_dir: str = None) -> None:
        app_name = "BackupTrackerMicro"
        user_agent = "BackupTracker (0.1.0)"
        use_cache = False
        force_cache = True
        sleep_ms = 25
        basic_auth = None
        cache_timeout_mins = 0
        super().__init__(app_name, root_endpoint, user_agent, sleep_ms, basic_auth,
                         config_dir, cache_dir, cache_timeout_mins, force_cache, use_cache)
        self.uid = self._get_id()['result']
        self.host = host
        self.service = service

    def get_backup_status(self, rows) -> None:
        e = "backup/status"
        p = {
            "rows": rows
        }
        res = self._run_rest(e, p, "post", None)
        if res.error:
            print(res.error_text)
            return ''
        return ""

    def get_backup_status_by_uid(self, uid) -> None:
        e = "backup/status"
        p = {
            "uid": uid
        }
        res = self._run_rest(e, p, "post", None)
        if res.error:
            print(res.error_text)
            return ''
        return ""

    def backup_status(self, size) -> None:
        e = "backup/status"
        p = {
            "uid": self.uid,
            "size": size
        }
        res = self._run_rest(e, p, "post", None)
        if res.error:
            print(res.error_text)
            return ''
        return ""

    def get_backup_events(self) -> list:
        e = "backup"
        p = {}
        res = self._run_rest(e, p, "get", None)
        if res.error:
            print(res.error_text)
            return ''
        return json.loads(res.response)

    def backup_event(self, event: BackupEvent) -> None:
        e = f"backup/{event.value}"
        p = {
            "host": self.host,
            "service": self.service,
            "uid": self.uid
        }
        res = self._run_rest(e, p, "post", None)
        if res.error:
            print(res.error_text)
            return ''
        return ""

    def _get_id(self) -> dict:
        e = "random/64"
        p = {}
        res = self._run_rest(e, p, "get", None)
        if res.error:
            print(res.error_text)
            return ''
        return json.loads(res.response)

==> backup_tracker_micro-0.1.2.tar.gz: backup_tracker_micro-0.1.2/src/backup_tracker_micro/backup.py <==

import json

from enum import Enum

from rest_client_micro import BaseRESTAPI


class BackupEvent(Enum):
    STARTED = "started"
    FINISHED = "finished"


class BackupTracker(BaseRESTAPI):

    host: str
    service: str
    uid: str

    def __init__(self, host: str, service: str, root_endpoint: str, uid: str = '', config_dir: str = None, cache_dir: str = None) -> None:
        app_name = "BackupTrackerMicro"
        user_agent = "BackupTracker (0.1.0)"
        use_cache = False
        force_cache = True
        sleep_ms = 25
        basic_auth = None
        cache_timeout_mins = 0
        super().__init__(app_name, root_endpoint, user_agent, sleep_ms, basic_auth,
                         config_dir, cache_dir, cache_timeout_mins, force_cache, use_cache)
        if uid == '':
            self.uid = self._get_id()['result']
        else:
            self.uid = uid
        self.host = host
        self.service = service

    def get_backup_status(self, rows) -> None:
        e = "backup/status"
        p = {
            "rows": rows
        }
        res = self._run_rest(e, p, "post", None)
        if res.error:
            print(res.error_text)
            return ''
        return ""

    def get_backup_status_by_uid(self, uid) -> None:
        e = "backup/status"
        p = {
            "uid": uid
        }
        res = self._run_rest(e, p, "post", None)
        if res.error:
            print(res.error_text)
            return ''
        return ""

    def backup_status(self, size) -> None:
        e = "backup/status"
        p = {
            "uid": self.uid,
            "size": size
        }
        res = self._run_rest(e, p, "post", None)
        if res.error:
            print(res.error_text)
            return ''
        return ""

    def get_backup_events(self) -> list:
        e = "backup"
        p = {}
        res = self._run_rest(e, p, "get", None)
        if res.error:
            print(res.error_text)
            return ''
        return json.loads(res.response)

    def backup_event(self, event: BackupEvent) -> None:
        e = f"backup/{event.value}"
        p = {
            "host": self.host,
            "service": self.service,
            "uid": self.uid
        }
        res = self._run_rest(e, p, "post", None)
        if res.error:
            print(res.error_text)
            return ''
        return self.uid

    def _get_id(self) -> dict:
        e = "random/64"
        p = {}
        res = self._run_rest(e, p, "get", None)
        if res.error:
            print(res.error_text)
            return ''
        return json.loads(res.response)
